Read-only schema for the metadata.
Re-exports
pub use crate::model::ParameterFlags;
Modules
- model
- Persisted data types for the metadata bundle.
Structs
- Binary
Expression - Read-only handle to a binary operator and its two operands.
- Buffer
- Read-only handle to a per-call buffer description.
- Database
- Read-only handle to an archived
model::Database. - Function
- Read-only handle to a monitored function or COM method.
- Interface
- Read-only handle to a COM interface.
- Metadata
- Read-only handle to one architecture’s metadata.
- Parameter
- Read-only handle to one function or method parameter.
- Type
- Read-only type signature for a parameter or return value.
- Unary
Expression - Read-only handle to a unary operator and its operand.
Enums
- Architecture
- CPU architecture used as the database key.
- Binary
Operator - Wire-format binary operator.
- Buffer
Direction - Data flow direction for a buffer parameter.
- Buffer
Phase - When a buffer’s length expression becomes evaluable.
- Expression
- Arithmetic expression evaluated at trace time to compute a buffer’s length in bytes.
- Type
Kind - Primitive kind of a leaf type.
- Unary
Operator - Wire-format unary operator.